"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GridEntityXMLType = void 0;
/**
 * The type of a grid entity as represented in a room XML/STB file.
 *
 * This is converted by the game to the GridEntityType enum.
 *
 * The `gridspawn` console command accepts `GridEntityXMLType` instead of `GridEntityType`.
 */
var GridEntityXMLType;
(function (GridEntityXMLType) {
    /** Corresponds to `GridEntityType.DECORATION` (1). */
    GridEntityXMLType[GridEntityXMLType["DECORATION"] = 0] = "DECORATION";
    /** Corresponds to `EntityType.EFFECT` (1000). */
    GridEntityXMLType[GridEntityXMLType["EFFECT"] = 999] = "EFFECT";
    /** Corresponds to `GridEntityType.ROCK` (2). */
    GridEntityXMLType[GridEntityXMLType["ROCK"] = 1000] = "ROCK";
    /** Corresponds to `GridEntityType.ROCK_BOMB` (5). */
    GridEntityXMLType[GridEntityXMLType["ROCK_BOMB"] = 1001] = "ROCK_BOMB";
    /**
     * An urn, mushroom, skull, polyp, or bucket, depending on what the backdrop type. For more
     * information, see the `getRockAltType` helper function.
     *
     * (Contrary to popular belief, the stage does not matter for the purposes of determining what the
     * `RockAltType` is.)
     *
     * Corresponds to `GridEntityType.ROCK_ALT` (6).
     */
    GridEntityXMLType[GridEntityXMLType["ROCK_ALT"] = 1002] = "ROCK_ALT";
    /**
     * The rocks with an "X" on them that produce soul hearts and other rewards when destroyed.
     *
     * Corresponds to `GridEntityType.ROCK_TINTED` (4).
     */
    GridEntityXMLType[GridEntityXMLType["ROCK_TINTED"] = 1003] = "ROCK_TINTED";
    /**
     * A marked skull that will always drop a Fool card.
     *
     * Corresponds to `GridEntityType.ROCK_ALT_2` (26).
     */
    GridEntityXMLType[GridEntityXMLType["ROCK_ALT_2"] = 1008] = "ROCK_ALT_2";
    /**
     * Rocks that will be destroyed when other nearby rocks are. In-game, it will be a
     * `GridEntityType.ROCK` (2) with a `VarData` of 1.
     */
    GridEntityXMLType[GridEntityXMLType["ROCK_EVENT"] = 1009] = "ROCK_EVENT";
    /** Corresponds to `GridEntityType.ROCK_SPIKED` (25). */
    GridEntityXMLType[GridEntityXMLType["ROCK_SPIKED"] = 1010] = "ROCK_SPIKED";
    /** Corresponds to `GridEntityType.ROCK_GOLD` (27). */
    GridEntityXMLType[GridEntityXMLType["ROCK_GOLD"] = 1011] = "ROCK_GOLD";
    /** Corresponds to `GridEntityType.TNT` (12). */
    GridEntityXMLType[GridEntityXMLType["TNT"] = 1300] = "TNT";
    /** Corresponds to `GridEntityType.FIREPLACE` (13), `FireplaceGridEntityVariant.NORMAL` (0). */
    GridEntityXMLType[GridEntityXMLType["FIREPLACE"] = 1400] = "FIREPLACE";
    /** Corresponds to `GridEntityType.FIREPLACE` (13), `FireplaceGridEntityVariant.RED` (1). */
    GridEntityXMLType[GridEntityXMLType["RED_FIREPLACE"] = 1410] = "RED_FIREPLACE";
    /** Corresponds to `GridEntityType.POOP` (14), `PoopGridEntityVariant.RED` (1). */
    GridEntityXMLType[GridEntityXMLType["POOP_RED"] = 1490] = "POOP_RED";
    /** Corresponds to `GridEntityType.POOP` (14), `PoopGridEntityVariant.RAINBOW` (4). */
    GridEntityXMLType[GridEntityXMLType["POOP_RAINBOW"] = 1494] = "POOP_RAINBOW";
    /** Corresponds to `GridEntityType.POOP` (14), `PoopGridEntityVariant.CORNY` (2). */
    GridEntityXMLType[GridEntityXMLType["POOP_CORNY"] = 1495] = "POOP_CORNY";
    /** Corresponds to `GridEntityType.POOP` (14), `PoopGridEntityVariant.GOLDEN` (3). */
    GridEntityXMLType[GridEntityXMLType["POOP_GOLDEN"] = 1496] = "POOP_GOLDEN";
    /** Corresponds to `GridEntityType.POOP` (14), `PoopGridEntityVariant.BLACK` (5). */
    GridEntityXMLType[GridEntityXMLType["POOP_BLACK"] = 1497] = "POOP_BLACK";
    /** Corresponds to `GridEntityType.POOP` (14), `PoopGridEntityVariant.WHITE` (6). */
    GridEntityXMLType[GridEntityXMLType["POOP_WHITE"] = 1498] = "POOP_WHITE";
    /**
     * Corresponds to `GridEntityType.POOP` (14) and the four "GIGA" variants of
     * `PoopGridEntityVariant`.
     */
    GridEntityXMLType[GridEntityXMLType["POOP_GIGA"] = 1499] = "POOP_GIGA";
    /** Corresponds to `GridEntityType.POOP` (14), `PoopGridEntityVariant.NORMAL` (0). */
    GridEntityXMLType[GridEntityXMLType["POOP"] = 1500] = "POOP";
    /** Corresponds to `GridEntityType.POOP` (14), `PoopGridEntityVariant.CHARMING` (11). */
    GridEntityXMLType[GridEntityXMLType["POOP_CHARMING"] = 1501] = "POOP_CHARMING";
    /** Corresponds to `GridEntityType.BLOCK` (3). */
    GridEntityXMLType[GridEntityXMLType["BLOCK"] = 1900] = "BLOCK";
    /** Corresponds to `GridEntityType.PILLAR` (24). */
    GridEntityXMLType[GridEntityXMLType["PILLAR"] = 1901] = "PILLAR";
    /** Corresponds to `GridEntityType.SPIKES` (8). */
    GridEntityXMLType[GridEntityXMLType["SPIKES"] = 1930] = "SPIKES";
    /** Corresponds to `GridEntityType.SPIKES_ON_OFF` (9). */
    GridEntityXMLType[GridEntityXMLType["SPIKES_ON_OFF"] = 1931] = "SPIKES_ON_OFF";
    /** Corresponds to `GridEntityType.SPIDER_WEB` (10). */
    GridEntityXMLType[GridEntityXMLType["SPIDER_WEB"] = 1940] = "SPIDER_WEB";
    /** Corresponds to `GridEntityType.WALL` (15). */
    GridEntityXMLType[GridEntityXMLType["WALL"] = 1999] = "WALL";
    /** Corresponds to `GridEntityType.PIT` (7). */
    GridEntityXMLType[GridEntityXMLType["PIT"] = 3000] = "PIT";
    /** Corresponds to `EntityType.EFFECT` (1000), `EffectVariant.FISSURE_SPAWNER` (192). */
    GridEntityXMLType[GridEntityXMLType["FISSURE_SPAWNER"] = 3001] = "FISSURE_SPAWNER";
    /**
     * Pits that will be filled in when nearby rocks are destroyed. In-game, it will be a
     * `GridEntityType.PIT` (7) with a `VarData` of 1.
     */
    GridEntityXMLType[GridEntityXMLType["PIT_EVENT"] = 3009] = "PIT_EVENT";
    /**
     * A key block.
     *
     * Corresponds to `GridEntityType.LOCK` (11).
     */
    GridEntityXMLType[GridEntityXMLType["LOCK"] = 4000] = "LOCK";
    /** Corresponds to `GridEntityType.PRESSURE_PLATE` (20). */
    GridEntityXMLType[GridEntityXMLType["PRESSURE_PLATE"] = 4500] = "PRESSURE_PLATE";
    /** Corresponds to `GridEntityType.STATUE` (21), `StatueVariant.DEVIL` (0). */
    GridEntityXMLType[GridEntityXMLType["STATUE_DEVIL"] = 5000] = "STATUE_DEVIL";
    /** Corresponds to `GridEntityType.STATUE` (21), `StatueVariant.ANGEL` (1). */
    GridEntityXMLType[GridEntityXMLType["STATUE_ANGEL"] = 5001] = "STATUE_ANGEL";
    /** Corresponds to `GridEntityType.TELEPORTER` (23). */
    GridEntityXMLType[GridEntityXMLType["TELEPORTER"] = 6100] = "TELEPORTER";
    /** Corresponds to `GridEntityType.TRAPDOOR` (17). */
    GridEntityXMLType[GridEntityXMLType["TRAPDOOR"] = 9000] = "TRAPDOOR";
    /** Corresponds to `GridEntityType.CRAWL_SPACE` (18). */
    GridEntityXMLType[GridEntityXMLType["CRAWL_SPACE"] = 9100] = "CRAWL_SPACE";
    /** Corresponds to `GridEntityType.GRAVITY` (19). */
    GridEntityXMLType[GridEntityXMLType["GRAVITY"] = 10000] = "GRAVITY";
})(GridEntityXMLType || (exports.GridEntityXMLType = GridEntityXMLType = {}));
