"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GridPath = void 0;
/**
 * GridPath is not an enum, but rather a variable integer that represents the cost it would take for
 * an entity to pass through a grid entity. This enum lists some standard cost values that the
 * vanilla game uses.
 */
var GridPath;
(function (GridPath) {
    GridPath[GridPath["NONE"] = 0] = "NONE";
    /**
     * Set by some enemies when they pass through a tile. De-prioritizes the tile for pathfinders.
     * Degrades over time in steps of 100.
     */
    GridPath[GridPath["WALKED_TILE"] = 900] = "WALKED_TILE";
    /** De-prioritizes the tile for pathfinders. Does not degrade. */
    GridPath[GridPath["FIREPLACE"] = 950] = "FIREPLACE";
    /**
     * Set by grid entities. Invalidates the tile for pathfinders. Impedes grounded player movement.
     * Does not degrade.
     */
    GridPath[GridPath["ROCK"] = 1000] = "ROCK";
    /** Invalidates the tile for pathfinders. Impedes grounded player movement. Does not degrade. */
    GridPath[GridPath["PIT"] = 3000] = "PIT";
    /**
     * Invalidates the tile for pathfinders. Impedes grounded player movement. Drops to 900 and then
     * degrades over time in steps of 100. (Grimaces reset the value every frame.)
     */
    GridPath[GridPath["GRIMACE"] = 3999] = "GRIMACE";
})(GridPath || (exports.GridPath = GridPath = {}));
