"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ItemConfigCardType = void 0;
/**
 * Corresponds to the "type" attribute in the "pocketitems.xml" file.
 *
 * Matches the `ItemConfig.CARDTYPE_` members of the `ItemConfig` class. In IsaacScript, we
 * reimplement this as an enum instead, since it is cleaner.
 *
 * Note that this enum is not to be confused with the `CardType` enum; the latter denotes the
 * in-game sub-type of the card, which is completely different.
 */
var ItemConfigCardType;
(function (ItemConfigCardType) {
    /** No valid card will have this type. */
    ItemConfigCardType[ItemConfigCardType["NULL"] = -1] = "NULL";
    /** A normal card with a brown back, like "0 - The Fool". */
    ItemConfigCardType[ItemConfigCardType["TAROT"] = 0] = "TAROT";
    /**
     * A playing card with a red back, like 2 of Clubs. This includes the Queen of Hearts and the
     * Joker. This does not include Suicide King or the Rules Card.
     */
    ItemConfigCardType[ItemConfigCardType["SUIT"] = 1] = "SUIT";
    /**
     * A left-facing rune like Hagalaz, a right-facing rune like Ansuz, a Black Rune, a Blank Rune, a
     * a Rune Shard, or a "soul" rune like Soul of Isaac.
     */
    ItemConfigCardType[ItemConfigCardType["RUNE"] = 2] = "RUNE";
    /**
     * A card that does not fall into any of the other categories, like a Chaos Card (42). This
     * category excludes non-cards such as Dice Shard.
     *
     * Most of the cards in this category have unique card-backs.
     *
     * 4 cards share the Magic the Gathering back:
     * - Chaos Card (42)
     * - Huge Growth (52)
     * - Ancient Recall (53)
     * - Era Walk (54)
     *
     * 3 cards have a red playing card back:
     * - Rules Card (44)
     * - Suicide King (46)
     * - ? Card (48)
     */
    ItemConfigCardType[ItemConfigCardType["SPECIAL"] = 3] = "SPECIAL";
    /** A Dice Shard, an Emergency Contact, or a Cracked Key. */
    ItemConfigCardType[ItemConfigCardType["SPECIAL_OBJECT"] = 4] = "SPECIAL_OBJECT";
    /** A reverse tarot card with a reddish-brown back, like "0 - The Fool?". */
    ItemConfigCardType[ItemConfigCardType["TAROT_REVERSE"] = 5] = "TAROT_REVERSE";
    /**
     * This is not a real `CardType`. Due to limitations in the API, getting the real type of modded
     * cards is not possible, so this value is returned instead.
     */
    ItemConfigCardType[ItemConfigCardType["MODDED"] = 6] = "MODDED";
})(ItemConfigCardType || (exports.ItemConfigCardType = ItemConfigCardType = {}));
