"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoomTransitionAnim = void 0;
var RoomTransitionAnim;
(function (RoomTransitionAnim) {
    /**
     * Mostly from using doors.
     *
     * Will play the correct walk animation regardless of the direction you use, as long as the
     * direction is in the same axis as the room you are traveling to.
     *
     * For example, if the room is on the left, it will play the correct animation whether you use
     * `Direction.LEFT` or `Direction.RIGHT`. If you use the wrong direction, it will just fade to the
     * next room (not fade to black, just fade). If you use `Direction.NO_DIRECTION`, it will perform
     * a fade to black.
     */
    RoomTransitionAnim[RoomTransitionAnim["WALK"] = 0] = "WALK";
    /**
     * The fade-in / fade-out used for Mom's Hand. If the direction is `Direction.NO_DIRECTION`, the
     * fade will be shorter.
     */
    RoomTransitionAnim[RoomTransitionAnim["FADE"] = 1] = "FADE";
    /**
     * The fade + pixelation effect used for secret item dungeon. (Direction does not affect the
     * pixelation length.)
     */
    RoomTransitionAnim[RoomTransitionAnim["PIXELATION"] = 2] = "PIXELATION";
    /**
     * Will play the teleport animation and sound, then the walk animation using the specified
     * direction. If `Direction.NO_DIRECTION` is used, it will perform a fade to white.
     */
    RoomTransitionAnim[RoomTransitionAnim["TELEPORT"] = 3] = "TELEPORT";
    /**
     * For Curse of the Maze.
     *
     * This is like `RoomTransitionAnim.WALK`, but better, since it will always play the walk
     * animation that you provide. Like `RoomTransitionAnim.WALK`, if you use
     * `Direction.NO_DIRECTION`, it will perform a fade to black.
     */
    RoomTransitionAnim[RoomTransitionAnim["MAZE"] = 4] = "MAZE";
    /** Works like `RoomTransitionAnim.MAZE` with respect to the direction used. */
    RoomTransitionAnim[RoomTransitionAnim["ANKH"] = 5] = "ANKH";
    /** Works like `RoomTransitionAnim.MAZE` with respect to the direction used. */
    RoomTransitionAnim[RoomTransitionAnim["DEAD_CAT"] = 6] = "DEAD_CAT";
    /**
     * Plays `SoundEffect.ONE_UP` upon entering the room.
     *
     * Works like `RoomTransitionAnim.MAZE` with respect to the direction used.
     */
    RoomTransitionAnim[RoomTransitionAnim["ONE_UP"] = 7] = "ONE_UP";
    /** Works like `RoomTransitionAnim.MAZE` with respect to the direction used. */
    RoomTransitionAnim[RoomTransitionAnim["COLLAR"] = 8] = "COLLAR";
    /** Works like `RoomTransitionAnim.MAZE` with respect to the direction used. */
    RoomTransitionAnim[RoomTransitionAnim["JUDAS_SHADOW"] = 9] = "JUDAS_SHADOW";
    /** Works like `RoomTransitionAnim.MAZE` with respect to the direction used. */
    RoomTransitionAnim[RoomTransitionAnim["LAZARUS"] = 10] = "LAZARUS";
    /**
     * For the Ventricle Razor teleport.
     *
     * Makes the player invisible during the transition. If used to change into the same room, the
     * player's visibility won't be restored. If the direction is `Direction.NO_DIRECTION`, the fade
     * will be shorter.
     */
    RoomTransitionAnim[RoomTransitionAnim["WOMB_TELEPORT"] = 11] = "WOMB_TELEPORT";
    /**
     * For the Glowing Hourglass teleport.
     *
     * Using this animation will ignore the room index and the direction provided.
     */
    RoomTransitionAnim[RoomTransitionAnim["GLOWING_HOURGLASS"] = 12] = "GLOWING_HOURGLASS";
    /** Works like `RoomTransitionAnim.MAZE` with respect to the direction used. */
    RoomTransitionAnim[RoomTransitionAnim["D7"] = 13] = "D7";
    /** Works like `RoomTransitionAnim.MAZE` with respect to the direction used. */
    RoomTransitionAnim[RoomTransitionAnim["MISSING_POSTER"] = 14] = "MISSING_POSTER";
    /** No transition; goes directly to the boss intro cutscene (for the Backasswards challenge). */
    RoomTransitionAnim[RoomTransitionAnim["BOSS_FORCED"] = 15] = "BOSS_FORCED";
    /**
     * For a Card Reading teleport.
     *
     * Works like `RoomTransitionAnim.WOMB_TELEPORT`.
     */
    RoomTransitionAnim[RoomTransitionAnim["PORTAL_TELEPORT"] = 16] = "PORTAL_TELEPORT";
    /**
     * For the Forgotten's Birthright effect.
     *
     * Works like `RoomTransitionAnim.FADE`.
     */
    RoomTransitionAnim[RoomTransitionAnim["FORGOTTEN_TELEPORT"] = 17] = "FORGOTTEN_TELEPORT";
    /**
     * Plays the mirror exit sound and a fade to white animation.
     *
     * If the direction is `Direction.NO_DIRECTION`, the fade will be shorter.
     */
    RoomTransitionAnim[RoomTransitionAnim["FADE_MIRROR"] = 18] = "FADE_MIRROR";
    /** Works like `RoomTransitionAnim.FADE`. */
    RoomTransitionAnim[RoomTransitionAnim["MINECART"] = 19] = "MINECART";
    /**
     * The player lies down, the screen fades to black, and the player lies down and gets up.
     *
     * Ignores the direction, but using `Direction.NO_DIRECTION` will make the fade shorter.
     *
     * The game is paused during the lying down and getting up animation.
     */
    RoomTransitionAnim[RoomTransitionAnim["DEATH_CERTIFICATE"] = 20] = "DEATH_CERTIFICATE";
})(RoomTransitionAnim || (exports.RoomTransitionAnim = RoomTransitionAnim = {}));
